@@ -28,36 +28,6 @@ use Test::Run::Straps::StrapsTotalsObj;
 
 use Test::Run::Obj::Error;
 
-my @fields= (qw(
-    bailout_reason
-    callback
-    Debug
-    error
-    exception
-    file
-    _file_totals
-    _is_macos
-    _is_win32
-    next_test_num
-    _old5lib
-    _parser
-    results
-    saw_bailout
-    saw_header
-    _seen_header
-    Switches
-    Switches_Env
-    Test_Interpreter
-    todo
-    too_many_tests
-    totals
-));
-
-sub _get_private_fields
-{
-    return [@fields];
-}
-
 has 'bailout_reason' => (is => "rw", isa => "Str");
 has 'callback' => (is => "rw", isa => "Maybe[CodeRef]");
 has 'Debug' => (is => "rw", isa => "Bool");
@@ -66,9 +36,15 @@ has 'exception' => (is => "rw", isa => "Any");
 has 'file' => (is => "rw", isa => "Str");
 has '_file_totals' =>
     (is => "rw", isa => "Test::Run::Straps::StrapsTotalsObj");
-has '_is_macos' => (is => "rw", isa => "Bool");
-has '_is_win32' => (is => "rw", isa => "Bool");
-has '_is_vms' => (is => "rw", isa => "Bool");
+has '_is_macos' => (is => "rw", isa => "Bool", 
+    default => sub { return ($^O eq "MacOS"); },
+);
+has '_is_win32' => (is => "rw", isa => "Bool",
+    default => sub { return ($^O =~ m{\A(?:MS)?Win32\z}); },
+);
+has '_is_vms' => (is => "rw", isa => "Bool", 
+    default => sub { return ($^O eq "VMS"); },
+);
 has 'last_test_print' => (is => "rw", isa => "Bool");
 has 'next_test_num' => (is => "rw", isa => "Num");
 has '_old5lib' => (is => "rw", isa => "Maybe[Str]");
@@ -81,10 +57,10 @@ has '_seen_header' => (is => "rw", isa => "Num");
 has 'Switches' => (is => "rw", isa => "Maybe[Str]");
 has 'Switches_Env' => (is => "rw", isa => "Maybe[Str]");
 has 'Test_Interpreter' => (is => "rw", isa => "Maybe[Str]");
-has 'todo' => (is => "rw", isa => "HashRef");
+has 'todo' => (is => "rw", isa => "HashRef", default => sub { +{} },);
 has 'too_many_tests' => (is => "rw", isa => "Bool");
 has 'totals' =>
-    (is => "rw", isa => "HashRef");
+    (is => "rw", isa => "HashRef", default => sub { +{} },);
 
 
 =head2 my $strap = Test::Run::Straps->new();
@@ -93,22 +69,6 @@ Initialize a new strap.
 
 =cut
 
-sub _init
-{
-    my $self = shift;
-
-    $self->maybe::next::method(@_);
-
-    $self->_is_vms($^O eq "VMS");
-    $self->_is_win32($^O =~ m{\A(?:MS)?Win32\z});
-    $self->_is_macos($^O eq "MacOS");
-
-    $self->totals(+{});
-    $self->todo(+{});
-
-    return 0;
-}
-
 sub _start_new_file
 {
     my $self = shift;
